@@ -1,10 +1,10 @@
 #' Effect size for ANOVA
 #'
-#' Functions to compute effect size measures for ANOVAs, such as Eta
-#' \eqn{(\eta)}{}, Omega \eqn{(\omega)}{} and Epsilon \eqn{(\epsilon)}{}
-#' squared, and Cohen's f (or their partialled versions) for ANOVA tables. These
-#' indices represent an estimate of how much variance in the response variables
-#' is accounted for by the explanatory variable(s).
+#' Functions to compute effect size measures for ANOVAs, such as Eta-
+#' (\eqn{\eta}), Omega- (\eqn{\omega}) and Epsilon- (\eqn{\epsilon}) squared,
+#' and Cohen's f (or their partialled versions) for ANOVA tables. These indices
+#' represent an estimate of how much variance in the response variables is
+#' accounted for by the explanatory variable(s).
 #' \cr\cr
 #' When passing models, effect sizes are computed using the sums of squares
 #' obtained from `anova(model)` which might not always be appropriate. See
@@ -18,8 +18,8 @@
 #'   calculated taking these observed variables into account. For `afex_aov`
 #'   model, when `generalized = TRUE`, the observed variables are extracted
 #'   automatically from the fitted model, if they were provided then.
+#' @param verbose Toggle warnings and messages on or off.
 #' @inheritParams chisq_to_phi
-#' @inheritParams standardize
 #' @param ... Arguments passed to or from other methods.
 #'   - Can be `include_intercept = TRUE` to include the effect size for the intercept.
 #'   - For Bayesian models, arguments passed to `ss_function`.
@@ -64,10 +64,9 @@
 #' analogous to adjusted R2 (Allen, 2017, p. 382), and has been found to be less
 #' biased (Carroll & Nordholm, 1975).
 #' \cr\cr
-#' (Note that for \eqn{\omega_p^2}{Omega2p} and \eqn{\epsilon_p^2}{Epsilon2p} it
-#' is possible to compute a negative number; even though this doesn't make any
-#' practical sense, it is recommended to report the negative number and not a
-#' 0.)
+#' (Note that for Omega- and Epsilon-squared it is possible to compute a
+#' negative number; even though this doesn't make any practical sense, it is
+#' recommended to report the negative number and not a 0.)
 #'
 #' ## Cohen's f
 #' Cohen's f can take on values between zero, when the population means are all
@@ -90,29 +89,30 @@
 #' effect size in the sample data). See [rstantools::posterior_predict()] for
 #' more info.
 #'
-#' @inheritSection effectsize-CIs Confidence Intervals
-#' @inheritSection effectsize-CIs CI Contains Zero
-#'
+#' @inheritSection effectsize_CIs Confidence (Compatibility) Intervals (CIs)
+#' @inheritSection effectsize_CIs CIs and Significance Tests
 #'
 #' @seealso [F_to_eta2()]
 #' @family effect size indices
 #'
 #' @examples
 #' \donttest{
-#' library(effectsize)
+#' data(mtcars)
 #' mtcars$am_f <- factor(mtcars$am)
 #' mtcars$cyl_f <- factor(mtcars$cyl)
 #'
 #' model <- aov(mpg ~ am_f * cyl_f, data = mtcars)
 #'
-#' eta_squared(model)
+#' (eta2 <- eta_squared(model))
+#'
+#' # More types:
+#' eta_squared(model, partial = FALSE)
 #' eta_squared(model, generalized = "cyl_f")
 #' omega_squared(model)
 #' epsilon_squared(model)
 #' cohens_f(model)
-#' (etas <- eta_squared(model, partial = FALSE))
 #'
-#' if (require(see)) plot(etas)
+#' if (require(see)) plot(eta2)
 #'
 #' model0 <- aov(mpg ~ am_f + cyl_f, data = mtcars) # no interaction
 #' cohens_f_squared(model0, model2 = model)
@@ -120,9 +120,11 @@
 #' ## Interpretation of effect sizes
 #' ## -------------------------------------
 #'
-#' interpret_omega_squared(0.15, rules = "field2013")
-#' interpret_eta_squared(0.15, rules = "cohen1992")
-#' interpret_epsilon_squared(0.15, rules = "cohen1992")
+#' interpret_omega_squared(0.10, rules = "field2013")
+#' interpret_eta_squared(0.10, rules = "cohen1992")
+#' interpret_epsilon_squared(0.10, rules = "cohen1992")
+#'
+#' interpret(eta2, rules = "cohen1992")
 #'
 #' # Recommended: Type-3 effect sizes + effects coding
 #' # -------------------------------------------------
@@ -219,20 +221,22 @@
 eta_squared <- function(model,
                         partial = TRUE,
                         generalized = FALSE,
-                        ci = 0.9,
+                        ci = 0.95, alternative = "greater",
                         verbose = TRUE,
                         ...) {
+  alternative <- match.arg(alternative, c("greater", "two.sided", "less"))
   out <- .anova_es(
     model,
     type = "eta",
     partial = partial,
     generalized = generalized,
-    ci = ci,
+    ci = ci, alternative = alternative,
     verbose = verbose,
     ...
   )
-  if (!inherits(model, "htest")) class(out) <- unique(c("effectsize_anova","effectsize_table", "see_effectsize_table", class(out)))
+  class(out) <- unique(c("effectsize_anova","effectsize_table", "see_effectsize_table", class(out)))
   if ("CI" %in% colnames(out)) attr(out, "ci_method") <- list(method = "ncp", distribution = "F")
+  attr(out, "approximate") <- isTRUE(attr(out, "approximate", exact = TRUE))
   return(out)
 }
 
@@ -240,12 +244,14 @@ eta_squared <- function(model,
 #' @export
 omega_squared <- function(model,
                           partial = TRUE,
-                          ci = 0.9,
+                          ci = 0.95, alternative = "greater",
                           verbose = TRUE,
                           ...) {
-  out <- .anova_es(model, type = "omega", partial = partial, ci = ci, verbose = verbose, ...)
-  if (!inherits(model, "htest")) class(out) <- unique(c("effectsize_anova","effectsize_table", "see_effectsize_table", class(out)))
+  alternative <- match.arg(alternative, c("greater", "two.sided", "less"))
+  out <- .anova_es(model, type = "omega", partial = partial, ci = ci, alternative = alternative, verbose = verbose, ...)
+  class(out) <- unique(c("effectsize_anova","effectsize_table", "see_effectsize_table", class(out)))
   if ("CI" %in% colnames(out)) attr(out, "ci_method") <- list(method = "ncp", distribution = "F")
+  attr(out, "approximate") <- isTRUE(attr(out, "approximate", exact = TRUE))
   return(out)
 }
 
@@ -253,12 +259,14 @@ omega_squared <- function(model,
 #' @export
 epsilon_squared <- function(model,
                             partial = TRUE,
-                            ci = 0.9,
+                            ci = 0.95, alternative = "greater",
                             verbose = TRUE,
                             ...) {
-  out <- .anova_es(model, type = "epsilon", partial = partial, ci = ci, verbose = verbose, ...)
-  if (!inherits(model, "htest")) class(out) <- unique(c("effectsize_anova","effectsize_table", "see_effectsize_table", class(out)))
+  alternative <- match.arg(alternative, c("greater", "two.sided", "less"))
+  out <- .anova_es(model, type = "epsilon", partial = partial, ci = ci, alternative = alternative, verbose = verbose, ...)
+  class(out) <- unique(c("effectsize_anova","effectsize_table", "see_effectsize_table", class(out)))
   if ("CI" %in% colnames(out)) attr(out, "ci_method") <- list(method = "ncp", distribution = "F")
+  attr(out, "approximate") <- isTRUE(attr(out, "approximate", exact = TRUE))
   return(out)
 }
 
@@ -267,16 +275,17 @@ epsilon_squared <- function(model,
 #' @param model2 Optional second model for Cohen's f (/squared). If specified,
 #'   returns the effect size for R-squared-change between the two models.
 #' @export
-cohens_f <- function(model, partial = TRUE, ci = 0.9, squared = FALSE,
+cohens_f <- function(model, partial = TRUE, ci = 0.95, alternative = "greater", squared = FALSE,
                      verbose = TRUE,
                      model2 = NULL, ...) {
+  alternative <- match.arg(alternative, c("greater", "two.sided", "less"))
   if (!is.null(model2)) {
-    return(.cohens_f_delta(model, model2, ci = ci, squared = squared, verbose = verbose))
+    return(.cohens_f_delta(model, model2, ci = ci, alternative = alternative, squared = squared, verbose = verbose))
   }
 
   res <- eta_squared(model,
     partial = partial,
-    ci = ci,
+    ci = ci, alternative = alternative,
     verbose = verbose,
     ...
   )
@@ -303,19 +312,20 @@ cohens_f <- function(model, partial = TRUE, ci = 0.9, squared = FALSE,
   }
 
   if ("CI" %in% colnames(res)) attr(res, "ci_method") <- list(method = "ncp", distribution = "F")
-  if (!inherits(model, "htest")) class(res) <- unique(c("effectsize_anova","effectsize_table", "see_effectsize_table", class(res)))
+  class(res) <- unique(c("effectsize_anova","effectsize_table", "see_effectsize_table", class(res)))
+  attr(res, "approximate") <- isTRUE(attr(res, "approximate", exact = TRUE))
   res
 }
 
 #' @rdname eta_squared
 #' @export
-cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
+cohens_f_squared <- function(model, partial = TRUE, ci = 0.95, alternative = "greater", squared = TRUE,
                              verbose = TRUE,
                              model2 = NULL, ...) {
   cohens_f(
     model,
     partial = partial,
-    ci = ci,
+    ci = ci, alternative = alternative,
     squared = squared,
     verbose = verbose,
     model2 = model2,
@@ -326,7 +336,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
 
 #' @keywords internal
 #' @importFrom insight model_info
-.cohens_f_delta <- function(model, model2, ci = 0.9, squared = FALSE, verbose = TRUE) {
+.cohens_f_delta <- function(model, model2, ci = 0.95, alternative = "greater", squared = FALSE, verbose = TRUE) {
   # check
   if (!inherits(model, "lm") ||
       !inherits(model2, "lm") ||
@@ -340,13 +350,11 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
   # Anova
   ANOVA <- anova(model, model2)
   out <- F_to_f(ANOVA[2, "F"], abs(ANOVA[2, "Df"]), min(ANOVA["Res.Df"]),
-                ci = ci, squared = squared
-  )
+                ci = ci, alternative = alternative,
+                squared = squared)
 
-  if (requireNamespace("performance")) {
-    R2d <- performance::r2(model)[[1]] - performance::r2(model2)[[1]]
-    out$R2_delta <- abs(R2d)
-  }
+  R2d <- performance::r2(model)[[1]] - performance::r2(model2)[[1]]
+  out$R2_delta <- abs(R2d)
 
   return(out)
 }
@@ -359,7 +367,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
            type = c("eta", "omega", "epsilon"),
            partial = TRUE,
            generalized = FALSE,
-           ci = 0.9,
+           ci = 0.95, alternative = "greater",
            verbose = TRUE,
            ...) {
     UseMethod(".anova_es")
@@ -371,7 +379,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                               type = c("eta", "omega", "epsilon"),
                               partial = TRUE,
                               generalized = FALSE,
-                              ci = 0.9,
+                              ci = 0.95, alternative = "greater",
                               verbose = TRUE,
                               ...) {
   .anova_es.anova(
@@ -380,6 +388,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
     partial = partial,
     generalized = generalized,
     ci = ci,
+    alternative = alternative,
     verbose = verbose
   )
 }
@@ -391,7 +400,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                           type = c("eta", "omega", "epsilon"),
                           partial = TRUE,
                           generalized = FALSE,
-                          ci = 0.9,
+                          ci = 0.95, alternative = "greater",
                           verbose = TRUE,
                           ...) {
   if (!inherits(model, c("Gam", "anova"))) {
@@ -401,7 +410,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
       type = type,
       partial = partial,
       generalized = generalized,
-      ci = ci,
+      ci = ci, alternative = alternative,
       verbose = verbose,
       ...
     )
@@ -411,7 +420,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
   type <- match.arg(type)
 
   params <- parameters::model_parameters(model, verbose = verbose, effects = "fixed")
-  out <- .es_aov(as.data.frame(params), type, partial, generalized, ci, verbose = verbose, ...)
+  out <- .es_aov(as.data.frame(params), type, partial, generalized, ci, alternative, verbose = verbose, ...)
   if (is.null(attr(out, "anova_type"))) attr(out, "anova_type") <- attr(params, "anova_type")
   out
 }
@@ -421,7 +430,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                     type = c("eta", "omega", "epsilon"),
                     partial = TRUE,
                     generalized = FALSE,
-                    ci = 0.9,
+                    ci = 0.95, alternative = "greater",
                     verbose = TRUE,
                     include_intercept = FALSE,
                     ...) {
@@ -524,9 +533,11 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
       F_to_eta2(f,
         out$df,
         df_error,
-        ci = ci
+        ci = ci, alternative = alternative
       )[-1]
     )
+  } else {
+    alternative <- NULL
   }
 
 
@@ -542,6 +553,8 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
   attr(out, "generalized") <- generalized
   attr(out, "ci") <- ci
   attr(out, "anova_type") <- anova_type
+  attr(out, "approximate") <- FALSE
+  attr(out, "alternative") <- alternative
   out
 }
 
@@ -558,7 +571,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                               type = c("eta", "omega", "epsilon"),
                               partial = TRUE,
                               generalized = FALSE,
-                              ci = 0.9,
+                              ci = 0.95, alternative = "greater",
                               verbose = TRUE,
                               include_intercept = FALSE,
                               ...) {
@@ -575,7 +588,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
       type = type,
       partial = partial,
       generalized = generalized,
-      ci = ci,
+      ci = ci, alternative = alternative,
       verbose = verbose,
       include_intercept = include_intercept
     )
@@ -588,7 +601,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                         type = c("eta", "omega", "epsilon"),
                         partial = TRUE,
                         generalized = FALSE,
-                        ci = 0.9,
+                        ci = 0.95, alternative = "greater",
                         verbose = TRUE,
                         include_intercept = FALSE) {
   type <- match.arg(type)
@@ -684,9 +697,11 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
       F_to_eta2(f,
                 out$df,
                 df_residuals,
-                ci = ci
+                ci = ci, alternative = alternative
       )[-1]
     )
+  } else {
+    alternative <- NULL
   }
 
   out <- out[, colnames(out) %in% c(
@@ -709,6 +724,8 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
   attr(out, "partial") <- partial
   attr(out, "generalized") <- generalized
   attr(out, "ci") <- ci
+  attr(out, "approximate") <- FALSE
+  attr(out, "alternative") <- alternative
   out
 }
 
@@ -719,7 +736,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                           type = c("eta", "omega", "epsilon"),
                           partial = TRUE,
                           generalized = FALSE,
-                          ci = 0.9,
+                          ci = 0.95, alternative = "greater",
                           verbose = TRUE,
                           ...) {
   model <- stats::aov(model)
@@ -732,7 +749,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
     type = type,
     partial = partial,
     generalized = generalized,
-    ci = ci,
+    ci = ci, alternative = alternative,
     verbose = verbose,
     ...
   )
@@ -743,6 +760,8 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
   attr(out, "generalized") <- attr(params[[1]], "generalized")
   attr(out, "ci") <- attr(params[[1]], "ci", exact = TRUE)
   attr(out, "anova_type") <- anova_type
+  attr(out, "approximate") <- FALSE
+  attr(out, "alternative") <- if (is.numeric(attr(out, "ci"))) alternative
   out
 }
 
@@ -753,7 +772,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                             type = c("eta", "omega", "epsilon"),
                             partial = TRUE,
                             generalized = FALSE,
-                            ci = 0.9,
+                            ci = 0.95, alternative = "greater",
                             verbose = TRUE,
                             include_intercept = FALSE,
                             ...) {
@@ -774,7 +793,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
       partial = partial,
       type = type,
       generalized = generalized,
-      ci = ci,
+      ci = ci, alternative = alternative,
       verbose = verbose,
       include_intercept = include_intercept,
       ...
@@ -818,7 +837,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
     es_fun(par_table[[F_val]],
       par_table[[numDF]],
       par_table[[denDF]],
-      ci = ci
+      ci = ci, alternative = alternative
     )
   )
 
@@ -826,6 +845,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
   attr(out, "generalized") <- generalized
   attr(out, "ci") <- ci
   attr(out, "anova_type") <- anova_type
+  attr(out, "alternative") <- if (is.numeric(ci)) alternative
   out
 }
 
@@ -838,7 +858,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                                        type = c("eta", "omega", "epsilon"),
                                        partial = TRUE,
                                        generalized = FALSE,
-                                       ci = 0.9,
+                                       ci = 0.95, alternative = "greater",
                                        verbose = TRUE,
                                        ...) {
   if (verbose && !isTRUE(partial)) {
@@ -870,7 +890,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
       df_error <- i[i$Parameter == "Residuals", "df"]
       cbind(
         data.frame(Group = unique(i$Group), stringsAsFactors = FALSE),
-        .anova_es_model_params(i, f, df_num, df_error, type, ci)
+        .anova_es_model_params(i, f, df_num, df_error, type, ci, alternative)
       )
     }))
   } else {
@@ -898,12 +918,13 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
     } else {
       stop("Cannot extract degrees of freedom for the error term. Try passing the model object directly to 'eta_squared()'.")
     }
-    out <- .anova_es_model_params(model, f, df_num, df_error, type, ci)
+    out <- .anova_es_model_params(model, f, df_num, df_error, type, ci, alternative)
   }
 
   attr(out, "partial") <- partial
   attr(out, "generalized") <- generalized
   attr(out, "ci") <- ci
+  attr(out, "alternative") <- if (is.numeric(ci)) alternative
   out
 }
 
@@ -915,7 +936,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                             type = c("eta", "omega", "epsilon"),
                             partial = TRUE,
                             generalized = FALSE,
-                            ci = 0.9,
+                            ci = 0.95, alternative = "greater",
                             verbose = TRUE,
                             ...){
   if (!grepl("One-way", model$method))
@@ -929,7 +950,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
     )
   }
 
-  effectsize(model, type = type, ci = ci, verbose = verbose, ...)
+  effectsize(model, type = type, ci = ci, alternative = alternative, verbose = verbose, ...)
 }
 
 #' @keywords internal
@@ -937,7 +958,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                                 type = c("eta", "omega", "epsilon"),
                                 partial = TRUE,
                                 generalized = FALSE,
-                                ci = 0.9,
+                                ci = 0.95, alternative = "greater",
                                 verbose = TRUE,
                                 include_intercept = FALSE,
                                 ...) {
@@ -946,7 +967,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
   # .anova_es.anova(model, type = type,
   #                 partial = partial,
   #                 generalized = generalized,
-  #                 ci = ci,
+  #                 ci = ci, alternative = alternative,
   #                 verbose = verbose,
   #                 ...)
 
@@ -961,7 +982,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
   out <- .anova_es.parameters_model(model, type = type,
                                     partial = partial,
                                     generalized = generalized,
-                                    ci = ci,
+                                    ci = ci, alternative = alternative,
                                     verbose = verbose,
                                     ...)
   attr(out, "anova_type") <- anova_type
@@ -970,18 +991,19 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
 
 #' @keywords internal
 #' @importFrom stats anova
+#' @importFrom insight check_if_installed
 .anova_es.merMod <- function(model,
                              type = c("eta", "omega", "epsilon"),
                              partial = TRUE,
                              generalized = FALSE,
-                             ci = 0.9,
+                             ci = 0.95, alternative = "greater",
                              verbose = TRUE,
                              ...) {
-  check_if_installed("lmerTest")
+  insight::check_if_installed("lmerTest")
 
   model <- lmerTest::as_lmerModLmerTest(model)
   model <- stats::anova(model)
-  .anova_es.anova(model, type = type, partial = partial, generalized = generalized, ci = ci, ...)
+  .anova_es.anova(model, type = type, partial = partial, generalized = generalized, ci = ci, alternative = alternative, ...)
 }
 
 #' @keywords internal
@@ -990,7 +1012,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                           type = c("eta", "omega", "epsilon"),
                           partial = TRUE,
                           generalized = FALSE,
-                          ci = 0.9,
+                          ci = 0.95, alternative = "greater",
                           verbose = TRUE,
                           ...) {
   type <- match.arg(type)
@@ -1036,7 +1058,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
       type = type,
       generalized = generalized,
       partial = partial,
-      ci = ci,
+      ci = ci, alternative = alternative,
       verbose = verbose
     )
 
@@ -1049,7 +1071,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                                type = c("eta", "omega", "epsilon"),
                                partial = TRUE,
                                generalized = FALSE,
-                               ci = 0.9,
+                               ci = 0.95, alternative = "greater",
                                verbose = TRUE,
                                include_intercept = FALSE,
                                ...) {
@@ -1066,8 +1088,8 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
         type = type,
         partial = partial,
         generalized = generalized,
-        ci = ci,
-        verbose = verbose,
+        ci = ci, alternative = alternative,
+        verbose = FALSE,
         include_intercept = include_intercept,
         ...
       )
@@ -1117,7 +1139,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
         type = type,
         partial = partial,
         generalized = generalized,
-        ci = ci,
+        ci = ci, alternative = alternative,
         verbose = verbose,
         include_intercept = include_intercept
       )
@@ -1131,6 +1153,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
   }
   out <- out[match(out$Parameter, orig_terms),]
   attr(out, "anova_type") <- attr(model, "type", exact = TRUE)
+  attr(out, "approximate") <- FALSE
   out
 }
 
@@ -1142,7 +1165,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                           type = c("eta", "omega", "epsilon"),
                           partial = TRUE,
                           generalized = FALSE,
-                          ci = 0.9,
+                          ci = 0.95, alternative = "greater",
                           verbose = TRUE,
                           ...) {
   if (!inherits(model, "anova.rms")) {
@@ -1157,7 +1180,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
 
   model <- model[rownames(model) != "ERROR", ]
 
-  out <- .anova_es.anova(model, type = type, partial = partial, generalized = generalized, ci = ci, ...)
+  out <- .anova_es.anova(model, type = type, partial = partial, generalized = generalized, ci = ci, alternative = alternative, ...)
   out$Parameter <- i[match(make.names(i), out$Parameter, nomatch = 0)]
   attr(out, "anova_type") <- 2
   out
@@ -1171,7 +1194,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                                 type = c("eta", "omega", "epsilon"),
                                 partial = TRUE,
                                 generalized = FALSE,
-                                ci = 0.9,
+                                ci = 0.95, alternative = "greater",
                                 verbose = TRUE,
                                 ...) {
   .anova_es(
@@ -1179,7 +1202,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
     type = type,
     partial = partial,
     generalized = generalized,
-    ci = ci,
+    ci = ci, alternative = alternative,
     verbose = verbose,
     ...
   )
@@ -1188,9 +1211,9 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
 # Utils -------------------------------------------------------------------
 
 #' @keywords internal
-.anova_es_model_params <- function(model, f, df_num, df_error, type, ci) {
+.anova_es_model_params <- function(model, f, df_num, df_error, type, ci, alternative) {
   # used by .anova_es.parameters_model
-  out <- .F_to_pve(stats::na.omit(f), df = df_num, df_error = df_error, ci = ci, es = paste0(type, "2"))
+  out <- .F_to_pve(stats::na.omit(f), df = df_num, df_error = df_error, ci = ci, alternative = alternative, es = paste0(type, "2"))
   out$Parameter <- model$Parameter[!is.na(f)]
   out[c(ncol(out), 1:(ncol(out) - 1))]
 }
