@@ -8,6 +8,9 @@ if (require("testthat") && require("effectsize")) {
     expect_equal(effectsize(model), cohens_d(x, y, pooled_sd = FALSE), ignore_attr = TRUE)
     expect_equal(effectsize(model, type = "g"), hedges_g(x, y, pooled_sd = FALSE), ignore_attr = TRUE)
 
+    model <- t.test(x, y, alternative = "less", conf.level = 0.8)
+    expect_equal(effectsize(model), cohens_d(x, y, pooled_sd = FALSE, alternative = "less", ci = 0.8), ignore_attr = TRUE)
+
     model <- t.test(x, y, paired = TRUE)
     expect_equal(effectsize(model), cohens_d(x, y, paired = TRUE), ignore_attr = TRUE)
 
@@ -51,13 +54,6 @@ if (require("testthat") && require("effectsize")) {
       effectsize(Xsq2)$Cramers_v
     )
 
-    Xsq3 <- chisq.test(table(mtcars$cyl))
-    expect_equal(effectsize(Xsq3)$Cramers_v, 0.19, tolerance = 0.01)
-    expect_equal(
-      effectsize(Xsq3)$Cramers_v,
-      cramers_v(table(mtcars$cyl))$Cramers_v
-    )
-
     # types
     expect_equal(
       effectsize(Xsq1, type = "phi"),
@@ -79,21 +75,18 @@ if (require("testthat") && require("effectsize")) {
       effectsize(Xsq4, type = "riskratio"),
       riskratio(contingency_table22)
     )
+
+    # goodness of fit
+    observed.dfc <<- c(119, 61)
+    expected.dfc <<- c(0.165, 0.835)
+
+    x <- chisq.test(x = observed.dfc, p = expected.dfc)
+    expect_error(effectsize(x, type = "v"))
   })
 
-  test_that("cor.test", {
+  test_that("cor.test / other", {
     r_ <- cor.test(iris$Sepal.Width, iris$Sepal.Length)
-    s_ <- suppressWarnings(cor.test(iris$Sepal.Width, iris$Sepal.Length, method = "spearman"))
-    t_ <- cor.test(iris$Sepal.Width, iris$Sepal.Length, method = "kendall")
-
-    expect_equal(effectsize(r_)[[1]], -0.118, tolerance = 0.01)
-    expect_equal(effectsize(s_)[[1]], -0.167, tolerance = 0.01)
-    expect_equal(effectsize(t_)[[1]], -0.077, tolerance = 0.01)
-
-    # no CI for tau or sr
-    expect_equal(ncol(effectsize(r_)), 4L)
-    expect_equal(ncol(effectsize(s_)), 1L)
-    expect_equal(ncol(effectsize(t_)), 1L)
+    expect_warning(effectsize(r_))
   })
 
   test_that("one way", {
@@ -182,6 +175,26 @@ if (require("testthat") && require("effectsize")) {
     expect_equal(H$CI_high, 1.68021, tolerance = 0.01)
   })
 
+  test_that("htest | Get args from htest", {
+    tt <- t.test(mtcars$hp, mtcars$mpg, alternative = "l", mu=-3, conf.level = 0.8, var.equal = TRUE)
+    expect_equal(cohens_d(tt), cohens_d(mtcars$hp, mtcars$mpg, alternative = "l", mu = -3, ci = 0.8), ignore_attr = TRUE)
+    expect_equal(cohens_d(tt, mu = -4, ci = 0.99, alternative = "t"),
+                 cohens_d(mtcars$hp, mtcars$mpg, mu = -4, ci = 0.99, alternative = "t"),
+                 ignore_attr = TRUE)
+
+    suppressWarnings(ww1 <- wilcox.test(mtcars$hp, mtcars$mpg, alternative = "l", mu = -3))
+    expect_equal(rank_biserial(ww1), rank_biserial(mtcars$hp, mtcars$mpg, alternative = "l", mu = -3), ignore_attr = TRUE)
+    expect_equal(rank_biserial(ww1, mu = -4, alternative = "t"),
+                 rank_biserial(mtcars$hp, mtcars$mpg, mu = -4, alternative = "t"),
+                 ignore_attr = TRUE)
+
+    suppressWarnings(ww2 <- wilcox.test(mtcars$hp, mtcars$mpg, alternative = "l", mu = -3,  conf.int = TRUE, conf.level = 0.8))
+    expect_equal(rank_biserial(ww2), rank_biserial(mtcars$hp, mtcars$mpg, alternative = "l", mu = -3, ci = 0.8), ignore_attr = TRUE)
+    expect_equal(rank_biserial(ww2, mu = -4, alternative = "t", ci = 0.99),
+                 rank_biserial(mtcars$hp, mtcars$mpg, mu = -4, alternative = "t", ci = 0.99),
+                 ignore_attr = TRUE)
+  })
+
 
   # aov ---------------------------------------------------------------------
   test_that("aov", {
